@@ -13,7 +13,7 @@ use XSLoader ();
 use B ();
 
 BEGIN {
-    our $VERSION = '2.05';
+    our $VERSION = '2.06';
 
     XSLoader::load(__PACKAGE__, $VERSION);
 }
@@ -102,12 +102,18 @@ sub B::PVMG::size {
             $size += B::Sizeof::MAGIC + $mg->LENGTH;
         }
     }
+    if (my $tied = tied(${ $sv->object_2svref })) {
+        return $size + B::svref_2object($tied)->size;
+    }
     $size;
 }
 
 sub B::AV::size {
     my $sv = shift;
     my $size = B::Sizeof::AV + B::Sizeof::XPVAV;
+    if (my $tied = tied(@{ $sv->object_2svref })) {
+        return $size + B::svref_2object($tied)->size;
+    }
     my @vals = $sv->ARRAY;
     for (my $i = 0; $i <= $sv->MAX; $i++) {
         my $sizecv = $vals[$i]->can('size') if $vals[$i];
@@ -121,6 +127,10 @@ sub B::HV::size {
     my $size = B::Sizeof::HV + B::Sizeof::XPVHV;
     #$size += length($sv->NAME);
 
+    if (my $tied = tied(%{ $sv->object_2svref })) {
+        return $size + B::svref_2object($tied)->size;
+    }
+
     $size += ($sv->MAX * (B::Sizeof::HE + B::Sizeof::HEK));
 
     my %vals = $sv->ARRAY;
